* TravelModelDataProcessing08-06-13.sas  Nicholas J. Linesch;
* Purpose: to create an input to ITHIM describing the regional VMT and PMT ;

* read in CHIS County to MPO Lookup Table;
proc import datafile='T:\ITHIM\Crosswalks\County_CHIS_lookup.csv' dbms=CSV out=county2CHIS replace;
getnames=yes;
run;

** read in VMT database file.  This comes from the regional activity based model;
proc import datafile='T:\ITHIM\OtherData\User Data -- SANDAG\VMT2008.xls' dbms=xls out=VMT_Daily_2008 replace;
getnames=yes;
sheet="db";
run;

** read in PMT database file;
proc import datafile='T:\ITHIM\OtherData\User Data -- SANDAG\PersonMilesInternal_Expanded.xls' dbms=xls out=PMT_Daily_2008 replace;
getnames=yes;
sheet="DB_SASREAD";
run;


** read in SD FTYPES - ITHIM FTYPES crosswalk;
** This is specific for the San Diego ABM.  For other regions it will need to be modified;
proc import datafile='T:\ITHIM\Crosswalks\SD_ABM_FTYPES_ITHIM.csv' dbms=csv out=SD_ABM_FTYPES_ITHIM replace;
getnames=yes;
run;

proc sql;
CREATE TABLE VMT AS
select A.*, B.ITHIM_Categories
from VMT_Daily_2008 A INNER JOIN SD_ABM_FTYPES_ITHIM B ON (A.f_type=B.SD_Categories);
run;

proc sql;
CREATE TABLE VMT_ITHIM AS
select ITHIM_Categories as f_type, mode, sum(VMT) as VMT
from VMT
GROUP BY ITHIM_Categories, mode;
run;

PROC SORT;
by mode;
run;

PROC MEANS NOPRINT data=VMT_ITHIM;
VAR VMT;
BY mode;
OUTPUT OUT= sumdata SUM(VMT)=vmt_total_Bymode;
run;

PROC PRINT DATA=sumdata;
 TITLE 'Summary Data Set';

PROC SORT;
by mode;
run;


DATA VMT_BYMODE;
MERGE VMT_ITHIM sumdata;
BY mode;
percent = VMT / vmt_total_Bymode * 100;
run;

PROC SORT;
BY mode;
run;

** Compile the VMT Item for a table;
proc sql;
CREATE TABLE item11 AS
SELECT 1 AS scenario_id, 11 as item_id,
'Vehicle miles traveled distance by facility type (VMT)' AS item_name,
'Miles per day' AS units,
'-' as urbrur, 
2008 as report_year,
'county' as geotype,
'San Diego' as geotype_name,
'06073' as geotype_code,
mode as mode,
'-' as mode_code,
"roadway type" as strata_type,
f_type as strata,
'-' as age_group,
'-' as sex,
'-' as unwt_n,
'-' as wt_n,
VMT as item_result,
'-' as se,
'-' as cv, 
DATETIME() as date
FROM VMT_ITHIM;
run;

data item11;
set item11;
format date datetime16.0;
run;

***  Calculation of PMT;
proc import datafile='T:\ITHIM\Crosswalks\ITHIM_Mode_toSDABMmode.csv' dbms=CSV out=ITHIM_Mode_toSDABMmode replace;
getnames=yes;
run;

data ITHIM_Mode_toSDABMmode;
set ITHIM_Mode_toSDABMmode (rename=(ITHIM_mode=mode));
run;


proc sort;
by mode;
run;


proc sql;
CREATE TABLE PMT AS
SELECT mode, sum(PMT) as PMT, sum(VMT) as VMT
FROM PMT_DAILY_2008
GROUP BY mode;
run;

proc sort;
by mode;
run;

DATA PMT;
MERGE PMT ITHIM_Mode_toSDABMmode;
BY mode;
run;

** Merge the VMT ratio with the PMT by mode;

DATA PMT;
MERGE PMT ITHIM_Mode_toSDABMmode;
BY mode;
run;

PROC SORT;
by sd_vmt_mode;
run;

DATA VMT_BYMODE;
set VMT_BYMODE (RENAME =(mode=sd_vmt_mode));
run;


proc sql;
CREATE TABLE PMT_BYFTYPE AS
select A.*, B.*
from PMT A LEFT JOIN VMT_BYMODE B ON (A.sd_vmt_mode=B.sd_vmt_mode);
run;

PROC SORT;
by mode;
run;

proc sql;
   alter table PMT_BYFTYPE
      add PMT_ftype num label='PMT_ftype';
	  run;

proc sql;
   update PMT_BYFTYPE
      set PMT_ftype=PMT*(percent/100);
run;

proc sql;
   update PMT_BYFTYPE
      set PMT_ftype=PMT
	  where mode='walk' OR mode='bike' OR mode='transit';
run;


** Compile the PMT Item for a table;
proc sql;
CREATE TABLE item10 AS
SELECT 1 AS scenario_id, 10 as item_id,
'Personal travel distance by facility type (PMT)' AS item_name,
'Miles per day' AS units,
'-' as urbrur, 
2008 as report_year,
'county' as geotype,
'San Diego' as geotype_name,
'06073' as geotype_code,
mode as mode,
'-' as mode_code,
"roadway type" as strata_type,
f_type as strata, 
'-' as age_group,
'-' as sex,
'-' as unwt_n,
'-' as wt_n,
PMT_ftype as item_result,
'-' as se,
'-' as cv, 
DATETIME() as date
FROM PMT_BYFTYPE;
run;

data item11;
set item11;
format date datetime16.0;
run;

data Items10and11;
format item_name $CHAR54.;
set item10 item11;
run;

data Items10and11;
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code mode mode_code strata_type strata strata_code age_group sex unwt_n wt_n item_result se cv version;
set Items10and11;
run;


proc export
data=Items10and11 outfile="T:\ITHIM\CalibrationData\Item10_PersonalTravelDistbyFtype\ITHIM_Items10and11_SD.csv" dbms=csv replace;
run;

proc export
data=Items10and11 outfile="T:\ITHIM\CalibrationData\Item10_PersonalTravelDistbyFtype\ITHIM_Items10and11_SD.xls" dbms=xls replace;
run;