* Item7_colon_colorectal5-27-13.sas  N Maizlish 5-27-13;
* Reads SDMF 2009-2011 files and creates sex-specific proportional;
* mortality for colon vs. colorectal cancers for California Counties;



* Read County to Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_County_FIPS2Region2010.xlsx' dbms=xlsx out= CA_County_FIPS2Region2010 replace;
getnames=yes;
run;
proc sort; by county_fips;run;

* Read County Code look-up table;
proc import datafile= 'H:\SDMF\sdmf_county_code.xls' dbms=xls out= sdmf_county_code replace;
getnames=yes;
run;
proc sort; by county; run; 

* Read California Population Denominator data;
* This data are to make sure all gender-county combinations are present;
proc import datafile= 'T:\ITHIM\2010Census\item5pop_age_sex2010.xlsx' dbms=xlsx out= item5pop_age_sex2010 replace;
getnames=yes;
run;

* Keep county population data;
data item5pop_age_sex2010 (keep = geotype_name county_fips age_cat sex unwt_n);
 set item5pop_age_sex2010; 
  if geotype = "CO" and age_cat < 5;
run;
proc sort; by county_fips sex; run;


* Read Death File;
* 2009;

DATA deaths2009;
INFILE 'H:\SDMF\2009\D09NOID.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

* Read Death File;
* 2010;

DATA deaths2010;
INFILE 'H:\SDMF\2010\D10NOID.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

* Read Death File;
* 2011;

DATA deaths2011;
INFILE 'H:\SDMF\2011\DSMF11_NOPI.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

* Subset colorectal cancers;
data colorectal_deaths09_11;
 set deaths2009 deaths2010 deaths2011;
if substr(cod,1,3) GE "C18" AND substr(cod,1,3) LE "C21";
run;
proc sort; by county;run;

Proc contents; run;

* Merge with county_fips lookpup table;
data colorectal_deaths09_11;
 merge colorectal_deaths09_11 sdmf_county_code;
by county;
run;

* Subset colon cancer deaths;
data colon_deaths09_11;
 set colorectal_deaths09_11;
if substr(cod,1,3) EQ "C18";
run;
Proc contents; run;

proc sort data= colorectal_deaths09_11; by county_fips sex;run;

* Aggregate Colorectal deaths by county and sex;
proc means data= colorectal_deaths09_11 noprint;
 by county_fips sex;
 var DOD;
output out = co_sex_colorectal N(dod) = cr_deaths09_11;
run;
proc sort; by county_fips sex;run;
Proc contents; run;

proc sort data= colon_deaths09_11; by county_fips sex;run;

* Aggregate colon cancer deaths by county and sex;
proc means data= colon_deaths09_11 noprint;
 by county_fips sex;
 var DOD;
output out = co_sex_colon N(dod) = colon_deaths09_11;
run;
proc sort; by county_fips sex;run;
Proc contents; run;

* merge data sets;
data co_sex_colorectal_colon;
 merge item5pop_age_sex2010 co_sex_colorectal co_sex_colon;
 by county_fips sex;
run;

* Drop records with missing FIPS, age, or sex data;
data co_sex_colorectal_colon (drop = _type_ _freq_ unwt_N) ;
  set co_sex_colorectal_colon ;
 if county_fips NE "" AND sex NE .;
* if no colo-reactal cancers occurred, set to 1;
if colon_deaths09_11 = . then colon_deaths09_11 = 1;
if cr_deaths09_11 = .    then cr_deaths09_11 = 1;
geotype = "CO";

* item_result = colon_deaths09_11/ cr_deaths09_11;
run;
proc contents; run;

******************* Regional aggregation;
Proc sort data = co_sex_colorectal_colon; by county_fips; run;

data co_sex_colorectal_colon;
 merge co_sex_colorectal_colon CA_County_FIPS2Region2010;
 by county_fips;
run;

******** Begin aggregation of deaths and population over MPO*************;
* Read MPO Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_mpo2010.xls' dbms=xls out= CA_mpo2010 replace;
getnames=yes;
run;
proc sort; by mpo_code;run;

proc sort data= co_sex_colorectal_colon; by mpo_code sex;run;

* Aggregate sex cells by county for cause-specific mortality;
proc means data= co_sex_colorectal_colon noprint;
 by mpo_code sex;
 var colon_deaths09_11 cr_deaths09_11;
output out = mpo_sex_deaths  sum(colon_deaths09_11) = colon_deaths09_11 sum(cr_deaths09_11)= cr_deaths09_11;
run;

* Merge to pick up mpo name;

proc sort; by mpo_code;run;

data mpo_sex_deaths (rename = (mpo_name=geotype_name mpo_code=geotype_code sex=gender colon_deaths09_11=numerator cr_deaths09_11=denominator) drop =_freq_ _type_ age_group);
merge mpo_sex_deaths CA_mpo2010;
by mpo_code;
geotype = "MPO";
age_group = "-";
run;
Proc contents;run;

******** END aggregation of deaths and population over MPO*************;


******** Begin aggregation of deaths and population over MEGAREGION*************;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_megaregion2010.xls' dbms=xls out= CA_megaregion2010 replace;
getnames=yes;
run;
proc sort; by megaregion_code;run;

proc sort data= co_sex_colorectal_colon; by megaregion_code sex;run;

* Aggregate sex cells by county for cause-specific mortality;
proc means data= co_sex_colorectal_colon noprint;
 by megaregion_code sex;
 var colon_deaths09_11 cr_deaths09_11;
output out = megaregion_sex_deaths  sum(colon_deaths09_11) = colon_deaths09_11 sum(cr_deaths09_11)= cr_deaths09_11;
run;

* Merge to pick up megaregion name;

proc sort; by megaregion_code;run;

data megaregion_sex_deaths (rename = (megaregion_name=geotype_name megaregion_code=geotype_code sex=gender colon_deaths09_11=numerator cr_deaths09_11=denominator) drop =_freq_ _type_ age_group);
merge megaregion_sex_deaths CA_megaregion2010;
by megaregion_code;
geotype = "megaregion";
run;
Proc contents;run;

******** END aggregation of deaths and population over MEGAREGION*************;


* Rename variables in County file;
data co_sex_colorectal_colon (rename=(countyname=geotype_name county_fips = geotype_code sex=gender colon_deaths09_11=numerator cr_deaths09_11=denominator));
 set co_sex_colorectal_colon (drop = region_name region_code mpo_code mpo_name megaregion_name megaregion_code age_cat);
run;

* reformat for item7 export;
data item7;
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code mode mode_code strata_type strata strata_code age_group sex numerator denominator item_result se cv date ;

format geotype $CHAR30.;
format geotype_name $CHAR30.;

 set co_sex_colorectal_colon mpo_sex_deaths megaregion_sex_deaths;

 scenario_id=1;
 item_id = 7;
 Item_name  = "Proportion of colon cancers from all colo-rectal cancers";
 units = "percent";
 urbrur = 1;
 report_year = "2009-2011";
 age_group="-";
 strata_code = "-";
 strata="-";
 strata_type="-";
 mode= "-";
 mode_code= "-"; 
 item_result = numerator/denominator;
 se= ((item_result*(1-item_result))/denominator)**.5;
 cv= se/item_result;
 if item_result > .5 then cv=se/(1-item_result);
 date = DATETIME();
 format date datetime16.0;
 if gender=1 then sex='m';
 if gender=2 then sex='f';
 if geotype="CO" then geotype="county";
run;

data item7 (drop=gender);
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code mode mode_code strata_type strata strata_code age_group sex numerator denominator item_result se cv date ;
set item7;
run;


* Sort file for export;
proc sort; by geotype geotype_name sex; run;

* Export County and region as CSV file;
proc export data= item7 outfile='T:\ITHIM\Outputs\ITHIM_item7mega_mpo_co.csv' dbms=CSV replace;
run;

* Export County and region file as xlsx file;
proc export data= item7 outfile='T:\ITHIM\Outputs\ITHIM_item7mega_mpo_co.xls' dbms=xls replace;
run;
